@@ -58,6 +58,15 @@ struct _NbtkAdjustmentPrivate
   gdouble page_increment;
   gdouble page_size;
 
+  /* For signal emission/notification */
+  guint lower_source;
+  guint upper_source;
+  guint value_source;
+  guint step_inc_source;
+  guint page_inc_source;
+  guint page_size_source;
+  guint changed_source;
+
   /* For interpolation */
   ClutterTimeline *interpolation;
   gdouble old_position;
@@ -235,11 +244,32 @@ stop_interpolation (NbtkAdjustment *adjustment)
     }
 }
 
+static void
+nbtk_adjustment_remove_idle (guint *source)
+{
+  if (*source)
+    {
+      g_source_remove (*source);
+      *source = 0;
+    }
+}
+
 static void
 nbtk_adjustment_dispose (GObject *object)
 {
+  NbtkAdjustmentPrivate *priv = NBTK_ADJUSTMENT (object)->priv;
+
   stop_interpolation (NBTK_ADJUSTMENT (object));
 
+  /* Remove idle handlers */
+  nbtk_adjustment_remove_idle (&priv->value_source);
+  nbtk_adjustment_remove_idle (&priv->lower_source);
+  nbtk_adjustment_remove_idle (&priv->upper_source);
+  nbtk_adjustment_remove_idle (&priv->page_inc_source);
+  nbtk_adjustment_remove_idle (&priv->step_inc_source);
+  nbtk_adjustment_remove_idle (&priv->page_size_source);
+  nbtk_adjustment_remove_idle (&priv->changed_source);
+
   G_OBJECT_CLASS (nbtk_adjustment_parent_class)->dispose (object);
 }
 
@@ -387,6 +417,93 @@ nbtk_adjustment_get_value (NbtkAdjustment *adjustment)
     return priv->value;
 }
 
+static gboolean
+nbtk_adjustment_value_notify_cb (NbtkAdjustment *adjustment)
+{
+  ClutterTimeline *interpolation;
+  NbtkAdjustmentPrivate *priv = adjustment->priv;
+
+  priv->value_source = 0;
+
+  /* Temporarily set the interpolation timeline to NULL so that
+   * if nbtk_adjustment_get_value gets called in this callback,
+   * it will get the interpolated value and not just the final
+   * value.
+   */
+  interpolation = priv->interpolation;
+  priv->interpolation = NULL;
+  g_object_notify (G_OBJECT (adjustment), "value");
+  priv->interpolation = interpolation;
+
+  return FALSE;
+}
+
+static gboolean
+nbtk_adjustment_lower_notify_cb (NbtkAdjustment *adjustment)
+{
+  NbtkAdjustmentPrivate *priv = adjustment->priv;
+
+  priv->lower_source = 0;
+  g_object_notify (G_OBJECT (adjustment), "lower");
+
+  return FALSE;
+}
+
+static gboolean
+nbtk_adjustment_upper_notify_cb (NbtkAdjustment *adjustment)
+{
+  NbtkAdjustmentPrivate *priv = adjustment->priv;
+
+  priv->upper_source = 0;
+  g_object_notify (G_OBJECT (adjustment), "upper");
+
+  return FALSE;
+}
+
+static gboolean
+nbtk_adjustment_step_inc_notify_cb (NbtkAdjustment *adjustment)
+{
+  NbtkAdjustmentPrivate *priv = adjustment->priv;
+
+  priv->step_inc_source = 0;
+  g_object_notify (G_OBJECT (adjustment), "step-increment");
+
+  return FALSE;
+}
+
+static gboolean
+nbtk_adjustment_page_inc_notify_cb (NbtkAdjustment *adjustment)
+{
+  NbtkAdjustmentPrivate *priv = adjustment->priv;
+
+  priv->page_inc_source = 0;
+  g_object_notify (G_OBJECT (adjustment), "page-increment");
+
+  return FALSE;
+}
+
+static gboolean
+nbtk_adjustment_page_size_notify_cb (NbtkAdjustment *adjustment)
+{
+  NbtkAdjustmentPrivate *priv = adjustment->priv;
+
+  priv->page_size_source = 0;
+  g_object_notify (G_OBJECT (adjustment), "page-size");
+
+  return FALSE;
+}
+
+static gboolean
+nbtk_adjustment_emit_changed_cb (NbtkAdjustment *adjustment)
+{
+  NbtkAdjustmentPrivate *priv = adjustment->priv;
+
+  priv->changed_source = 0;
+  g_signal_emit (adjustment, signals[CHANGED], 0);
+
+  return FALSE;
+}
+
 void
 nbtk_adjustment_set_value (NbtkAdjustment *adjustment,
                            gdouble         value)
@@ -412,7 +529,12 @@ nbtk_adjustment_set_value (NbtkAdjustment *adjustment,
     {
       priv->value = value;
 
-      g_object_notify (G_OBJECT (adjustment), "value");
+      if (!priv->value_source)
+        priv->value_source =
+          g_idle_add_full (CLUTTER_PRIORITY_REDRAW,
+                           (GSourceFunc)nbtk_adjustment_value_notify_cb,
+                           adjustment,
+                           NULL);
     }
 }
 
@@ -447,8 +569,25 @@ nbtk_adjustment_clamp_page (NbtkAdjustment *adjustment,
       changed = TRUE;
     }
 
-  if (changed)
-    g_object_notify (G_OBJECT (adjustment), "value");
+  if (changed && !priv->value_source)
+    priv->value_source =
+      g_idle_add_full (CLUTTER_PRIORITY_REDRAW,
+                       (GSourceFunc)nbtk_adjustment_value_notify_cb,
+                       adjustment,
+                       NULL);
+}
+
+static void
+nbtk_adjustment_emit_changed (NbtkAdjustment *adjustment)
+{
+  NbtkAdjustmentPrivate *priv = adjustment->priv;
+
+  if (!priv->changed_source)
+    priv->changed_source =
+      g_idle_add_full (CLUTTER_PRIORITY_REDRAW,
+                       (GSourceFunc)nbtk_adjustment_emit_changed_cb,
+                       adjustment,
+                       NULL);
 }
 
 static gboolean
@@ -461,9 +600,14 @@ nbtk_adjustment_set_lower (NbtkAdjustment *adjustment,
     {
       priv->lower = lower;
 
-      g_signal_emit (adjustment, signals[CHANGED], 0);
+      nbtk_adjustment_emit_changed (adjustment);
 
-      g_object_notify (G_OBJECT (adjustment), "lower");
+      if (!priv->lower_source)
+        priv->lower_source =
+          g_idle_add_full (CLUTTER_PRIORITY_REDRAW,
+                           (GSourceFunc)nbtk_adjustment_lower_notify_cb,
+                           adjustment,
+                           NULL);
 
       /* Defer clamp until after construction. */
       if (!priv->is_constructing)
@@ -485,9 +629,14 @@ nbtk_adjustment_set_upper (NbtkAdjustment *adjustment,
     {
       priv->upper = upper;
 
-      g_signal_emit (adjustment, signals[CHANGED], 0);
+      nbtk_adjustment_emit_changed (adjustment);
 
-      g_object_notify (G_OBJECT (adjustment), "upper");
+      if (!priv->upper_source)
+        priv->upper_source =
+          g_idle_add_full (CLUTTER_PRIORITY_REDRAW,
+                           (GSourceFunc)nbtk_adjustment_upper_notify_cb,
+                           adjustment,
+                           NULL);
 
       /* Defer clamp until after construction. */
       if (!priv->is_constructing)
@@ -509,9 +658,14 @@ nbtk_adjustment_set_step_increment (NbtkAdjustment *adjustment,
     {
       priv->step_increment = step;
 
-      g_signal_emit (adjustment, signals[CHANGED], 0);
+      nbtk_adjustment_emit_changed (adjustment);
 
-      g_object_notify (G_OBJECT (adjustment), "step-increment");
+      if (!priv->step_inc_source)
+        priv->step_inc_source =
+          g_idle_add_full (CLUTTER_PRIORITY_REDRAW,
+                           (GSourceFunc)nbtk_adjustment_step_inc_notify_cb,
+                           adjustment,
+                           NULL);
 
       return TRUE;
     }
@@ -529,9 +683,14 @@ nbtk_adjustment_set_page_increment (NbtkAdjustment *adjustment,
     {
       priv->page_increment = page;
 
-      g_signal_emit (adjustment, signals[CHANGED], 0);
+      nbtk_adjustment_emit_changed (adjustment);
 
-      g_object_notify (G_OBJECT (adjustment), "page-increment");
+      if (!priv->page_inc_source)
+        priv->page_inc_source =
+          g_idle_add_full (CLUTTER_PRIORITY_REDRAW,
+                           (GSourceFunc)nbtk_adjustment_page_inc_notify_cb,
+                           adjustment,
+                           NULL);
 
       return TRUE;
     }
@@ -549,9 +708,14 @@ nbtk_adjustment_set_page_size (NbtkAdjustment *adjustment,
     {
       priv->page_size = size;
 
-      g_signal_emit (adjustment, signals[CHANGED], 0);
+      nbtk_adjustment_emit_changed (adjustment);
 
-      g_object_notify (G_OBJECT (adjustment), "page_size");
+      if (!priv->page_size_source)
+        priv->page_size_source =
+          g_idle_add_full (CLUTTER_PRIORITY_REDRAW,
+                           (GSourceFunc)nbtk_adjustment_page_size_notify_cb,
+                           adjustment,
+                           NULL);
 
       /* Well explicitely clamp after construction. */
       if (!priv->is_constructing)
@@ -601,7 +765,7 @@ nbtk_adjustment_set_values (NbtkAdjustment *adjustment,
     }
 
   if (emit_changed)
-    g_signal_emit (G_OBJECT (adjustment), signals[CHANGED], 0);
+    nbtk_adjustment_emit_changed (adjustment);
 
   g_object_thaw_notify (G_OBJECT (adjustment));
 }
