@@ -299,10 +299,13 @@ nbtk_bin_get_preferred_width (ClutterActor *self,
 {
   NbtkBinPrivate *priv = NBTK_BIN (self)->priv;
   gfloat min_width, natural_width;
+  gfloat available_height;
   NbtkPadding padding = { 0, };
 
   nbtk_widget_get_padding (NBTK_WIDGET (self), &padding);
 
+  available_height = for_height - padding.top - padding.bottom;
+
   min_width = natural_width = padding.left + padding.right;
 
   if (priv->child == NULL)
@@ -315,7 +318,7 @@ nbtk_bin_get_preferred_width (ClutterActor *self,
     }
   else
     {
-      clutter_actor_get_preferred_width (priv->child, for_height,
+      clutter_actor_get_preferred_width (priv->child, available_height,
                                          min_width_p,
                                          natural_width_p);
 
@@ -335,10 +338,13 @@ nbtk_bin_get_preferred_height (ClutterActor *self,
 {
   NbtkBinPrivate *priv = NBTK_BIN (self)->priv;
   gfloat min_height, natural_height;
+  gfloat available_width;
   NbtkPadding padding = { 0, };
 
   nbtk_widget_get_padding (NBTK_WIDGET (self), &padding);
 
+  available_width = for_width - padding.left - padding.right;
+
   min_height = natural_height = padding.top + padding.bottom;
 
   if (priv->child == NULL)
@@ -351,7 +357,7 @@ nbtk_bin_get_preferred_height (ClutterActor *self,
     }
   else
     {
-      clutter_actor_get_preferred_height (priv->child, for_width,
+      clutter_actor_get_preferred_height (priv->child, available_width,
                                           min_height_p,
                                           natural_height_p);
 
@@ -370,7 +376,7 @@ nbtk_bin_dispose (GObject *gobject)
 
   if (priv->child)
     {
-      clutter_actor_unparent (priv->child);
+      clutter_actor_destroy (priv->child);
       priv->child = NULL;
     }
 
