@@ -144,15 +144,9 @@ scrollable_get_adjustments (NbtkScrollable *scrollable,
                             NbtkAdjustment **vadjustment)
 {
   NbtkBoxLayoutPrivate *priv;
-  ClutterActor *actor, *stage;
 
   priv = (NBTK_BOX_LAYOUT (scrollable))->priv;
 
-  actor = CLUTTER_ACTOR (scrollable);
-  stage = clutter_actor_get_stage (actor);
-  if (G_UNLIKELY (stage == NULL))
-    stage = clutter_stage_get_default ();
-
   if (hadjustment)
     {
       if (priv->hadjustment)
@@ -160,18 +154,16 @@ scrollable_get_adjustments (NbtkScrollable *scrollable,
       else
         {
           NbtkAdjustment *adjustment;
-          gdouble width, stage_width, increment;
 
-          width = clutter_actor_get_width (actor);
-          stage_width = clutter_actor_get_width (stage);
-          increment = MAX (1.0, MIN (stage_width, width));
+          /* create an initial adjustment. this is filled with correct values
+           * as soon as allocate() is called */
 
-          adjustment = nbtk_adjustment_new (0,
-                                            0,
-                                            width,
+          adjustment = nbtk_adjustment_new (0.0,
+                                            0.0,
                                             1.0,
-                                            increment,
-                                            increment);
+                                            1.0,
+                                            1.0,
+                                            1.0);
 
           scrollable_set_adjustments (scrollable,
                                       adjustment,
@@ -188,18 +180,16 @@ scrollable_get_adjustments (NbtkScrollable *scrollable,
       else
         {
           NbtkAdjustment *adjustment;
-          gdouble height, stage_height, increment;
 
-          height = clutter_actor_get_height (actor);
-          stage_height = clutter_actor_get_height (stage);
-          increment = MAX (1.0, MIN (stage_height, height));
+          /* create an initial adjustment. this is filled with correct values
+           * as soon as allocate() is called */
 
-          adjustment = nbtk_adjustment_new (0,
-                                            0,
-                                            height,
+          adjustment = nbtk_adjustment_new (0.0,
+                                            0.0,
                                             1.0,
-                                            increment,
-                                            increment);
+                                            1.0,
+                                            1.0,
+                                            1.0);
 
           scrollable_set_adjustments (scrollable,
                                       priv->hadjustment,
@@ -394,12 +384,12 @@ nbtk_box_layout_dispose (GObject *object)
 {
   NbtkBoxLayoutPrivate *priv = NBTK_BOX_LAYOUT (object)->priv;
 
+  /* destroy the children
+   * clutter_actor_destroy() will call clutter_container_remove() which will
+   * remove the children from the internal list
+   */
   while (priv->children)
-    {
-      clutter_actor_unparent (CLUTTER_ACTOR (priv->children->data));
-
-      priv->children = g_list_delete_link (priv->children, priv->children);
-    }
+    clutter_actor_destroy (CLUTTER_ACTOR (priv->children->data));
 
   if (priv->hadjustment)
     {
@@ -430,13 +420,10 @@ nbtk_box_layout_get_preferred_width (ClutterActor *actor,
   nbtk_widget_get_padding (NBTK_WIDGET (actor), &padding);
 
   if (min_width_p)
-    *min_width_p = padding.left + padding.right;
+    *min_width_p = 0;
 
   if (natural_width_p)
-    *natural_width_p = padding.left + padding.right;
-
-  if (priv->children == NULL)
-    return;
+    *natural_width_p = 0;
 
   for (l = priv->children; l; l = g_list_next (l))
     {
@@ -480,6 +467,12 @@ nbtk_box_layout_get_preferred_width (ClutterActor *actor,
       if (natural_width_p)
         *natural_width_p += priv->spacing * (n_children - 1);
     }
+
+  if (min_width_p)
+    *min_width_p += padding.left + padding.right;
+
+  if (natural_width_p)
+    *natural_width_p += padding.left + padding.right;
 }
 
 static void
@@ -495,14 +488,13 @@ nbtk_box_layout_get_preferred_height (ClutterActor *actor,
 
   nbtk_widget_get_padding (NBTK_WIDGET (actor), &padding);
 
+
   if (min_height_p)
-    *min_height_p = padding.top + padding.bottom;
+    *min_height_p = 0;
 
   if (natural_height_p)
-    *natural_height_p = padding.top + padding.bottom;
+    *natural_height_p = 0;
 
-  if (priv->children == NULL)
-    return;
 
   for (l = priv->children; l; l = g_list_next (l))
     {
@@ -544,6 +536,12 @@ nbtk_box_layout_get_preferred_height (ClutterActor *actor,
       if (natural_height_p)
         *natural_height_p += priv->spacing * (n_children - 1);
     }
+
+  if (min_height_p)
+    *min_height_p += padding.top + padding.bottom;
+
+  if (natural_height_p)
+    *natural_height_p += padding.top + padding.bottom;
 }
 
 static void
@@ -572,10 +570,18 @@ nbtk_box_layout_allocate (ClutterActor          *actor,
                - padding.top
                - padding.bottom;
 
-  nbtk_box_layout_get_preferred_height (actor, avail_width, NULL,
-                                        &pref_height);
-  nbtk_box_layout_get_preferred_width (actor, avail_height, NULL,
-                                       &pref_width);
+  if (priv->is_vertical)
+    {
+      nbtk_box_layout_get_preferred_height (actor, avail_width, NULL,
+                                            &pref_height);
+      pref_width = avail_width;
+    }
+  else
+    {
+      nbtk_box_layout_get_preferred_width (actor, avail_height, NULL,
+                                           &pref_width);
+      pref_height = avail_height;
+    }
 
   /* update adjustments for scrolling */
   if (priv->vadjustment)
@@ -682,7 +688,7 @@ nbtk_box_layout_allocate (ClutterActor          *actor,
           else
             child_box.y2 = position + child_nat;
           child_box.x1 = padding.left;
-          child_box.x2 = avail_width;
+          child_box.x2 = avail_width + padding.left;
 
           _nbtk_allocate_fill (child, &child_box, xalign, yalign, xfill, yfill);
           clutter_actor_allocate (child, &child_box, flags);
@@ -706,7 +712,7 @@ nbtk_box_layout_allocate (ClutterActor          *actor,
             child_box.x2 = position + child_nat;
 
           child_box.y1 = padding.top;
-          child_box.y2 = avail_height;
+          child_box.y2 = avail_height + padding.top;
           _nbtk_allocate_fill (child, &child_box, xalign, yalign, xfill, yfill);
           clutter_actor_allocate (child, &child_box, flags);
 
