@@ -108,11 +108,9 @@ nbtk_combo_box_dispose (GObject *object)
 {
   NbtkComboBoxPrivate *priv = NBTK_COMBO_BOX (object)->priv;
 
-  G_OBJECT_CLASS (nbtk_combo_box_parent_class)->dispose (object);
-
   if (priv->label)
     {
-      g_object_unref (priv->label);
+      clutter_actor_destroy (priv->label);
       priv->label = NULL;
     }
 
@@ -123,6 +121,8 @@ nbtk_combo_box_dispose (GObject *object)
       stage = clutter_actor_get_stage (CLUTTER_ACTOR (object));
       clutter_container_remove_actor ((ClutterContainer*) stage, priv->popup);
     }
+
+  G_OBJECT_CLASS (nbtk_combo_box_parent_class)->dispose (object);
 }
 
 static void
@@ -130,13 +130,13 @@ nbtk_combo_box_finalize (GObject *object)
 {
   NbtkComboBoxPrivate *priv = NBTK_COMBO_BOX (object)->priv;
 
-  G_OBJECT_CLASS (nbtk_combo_box_parent_class)->finalize (object);
-
   if (priv->text_list)
     {
       g_slist_foreach (priv->text_list, (GFunc) g_free, NULL);
       g_slist_free (priv->text_list);
     }
+
+  G_OBJECT_CLASS (nbtk_combo_box_parent_class)->finalize (object);
 }
 
 static void
@@ -289,10 +289,6 @@ nbtk_combo_box_action_activated_cb (ClutterActor *popup,
   box->priv->index = index;
   g_object_notify ((GObject*) box, "index");
 
-  clutter_actor_animate (popup, CLUTTER_LINEAR, 250,
-                         "opacity", (guchar) 0,
-                         "signal-swapped::completed", clutter_actor_hide, popup,
-                         NULL);
 }
 
 static void
