@@ -20,6 +20,14 @@
  *
  */
 
+/**
+ * SECTION:nbtk-expander
+ * @short_description: a container which the user can show or hide its child
+ *
+ * #NbtkExpander is a single child container that allows the user to show or
+ * hide its child.
+ */
+
 #include "nbtk-marshal.h"
 #include "nbtk-expander.h"
 #include "nbtk-private.h"
@@ -32,13 +40,16 @@ G_DEFINE_TYPE_WITH_CODE (NbtkExpander, nbtk_expander, NBTK_TYPE_BIN,
                          G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_CONTAINER,
                                                 clutter_container_iface_init))
 
+static ClutterContainerIface *container_parent_class = NULL;
+
 #define GET_PRIVATE(o) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((o), NBTK_TYPE_EXPANDER, NbtkExpanderPrivate))
 
 enum {
   PROP_0,
 
-  PROP_EXPANDED
+  PROP_EXPANDED,
+  PROP_LABEL
 };
 
 enum
@@ -74,6 +85,9 @@ nbtk_expander_get_property (GObject *object,
     case PROP_EXPANDED:
       g_value_set_boolean (value, priv->expanded);
       break;
+    case PROP_LABEL:
+      g_value_set_string (value, clutter_text_get_text (CLUTTER_TEXT (priv->label)));
+      break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -90,6 +104,10 @@ nbtk_expander_set_property (GObject *object,
       nbtk_expander_set_expanded ((NbtkExpander *) object,
                                   g_value_get_boolean (value));
       break;
+    case PROP_LABEL:
+      nbtk_expander_set_label ((NbtkExpander *) object,
+                               g_value_get_string (value));
+      break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -106,6 +124,12 @@ nbtk_expander_dispose (GObject *object)
       priv->label = NULL;
     }
 
+  if (priv->arrow)
+    {
+      clutter_actor_unparent (priv->arrow);
+      priv->arrow = NULL;
+    }
+
   if (priv->timeline)
     {
       g_object_unref (priv->timeline);
@@ -440,9 +464,6 @@ nbtk_expander_allocate (ClutterActor          *actor,
 static void
 nbtk_expander_paint (ClutterActor *actor)
 {
-  if (!((NbtkExpander *) actor)->priv->expanded)
-    clutter_actor_hide (nbtk_bin_get_child ((NbtkBin*) actor));
-
   CLUTTER_ACTOR_CLASS (nbtk_expander_parent_class)->paint (actor);
 
   clutter_actor_paint (((NbtkExpander* ) actor)->priv->label);
@@ -554,10 +575,34 @@ nbtk_expander_foreach (ClutterContainer *container,
               user_data);
 }
 
+static void
+nbtk_expander_add (ClutterContainer *container,
+                   ClutterActor *actor)
+{
+  NbtkExpander *expander = NBTK_EXPANDER (container);
+  NbtkExpanderPrivate *priv = expander->priv;
+
+  /* Override the container add method so we can hide the actor if the
+     expander is not expanded */
+
+  /* chain up */
+  container_parent_class->add (container, actor);
+
+  if (!priv->expanded)
+    {
+      actor = nbtk_bin_get_child (NBTK_BIN (container));
+      if (actor)
+        clutter_actor_hide (actor);
+    }
+}
+
 static void
 clutter_container_iface_init (ClutterContainerIface *iface)
 {
+  container_parent_class = g_type_interface_peek_parent (iface);
+
   iface->foreach = nbtk_expander_foreach;
+  iface->add = nbtk_expander_add;
 }
 
 static void
@@ -593,6 +638,14 @@ nbtk_expander_class_init (NbtkExpanderClass *klass)
                                    PROP_EXPANDED,
                                    pspec);
 
+  pspec = g_param_spec_string ("label",
+                               "Label",
+                               "Expander title label.",
+                               NULL, G_PARAM_READWRITE);
+  g_object_class_install_property (object_class,
+                                   PROP_LABEL,
+                                   pspec);
+
   /**
    * NbtkExpander::expand-complete:
    * @expander: the object that received the signal
