@@ -243,6 +243,20 @@ nbtk_label_unmap (ClutterActor *actor)
   clutter_actor_unmap (priv->label);
 }
 
+static void
+nbtk_label_dispose (GObject *actor)
+{
+  NbtkLabelPrivate *priv = NBTK_LABEL (actor)->priv;
+
+  if (priv->label)
+    {
+      clutter_actor_destroy (priv->label);
+      priv->label = NULL;
+    }
+
+  G_OBJECT_CLASS (nbtk_label_parent_class)->dispose (actor);
+}
+
 static void
 nbtk_label_class_init (NbtkLabelClass *klass)
 {
@@ -254,6 +268,7 @@ nbtk_label_class_init (NbtkLabelClass *klass)
 
   gobject_class->set_property = nbtk_label_set_property;
   gobject_class->get_property = nbtk_label_get_property;
+  gobject_class->dispose = nbtk_label_dispose;
 
   actor_class->paint = nbtk_label_paint;
   actor_class->allocate = nbtk_label_allocate;
@@ -357,7 +372,7 @@ nbtk_label_set_text (NbtkLabel *label,
 ClutterActor*
 nbtk_label_get_clutter_text (NbtkLabel *label)
 {
-  g_return_val_if_fail (NBTK_LABEL (label), NULL);
+  g_return_val_if_fail (NBTK_IS_LABEL (label), NULL);
 
   return label->priv->label;
 }
