@@ -119,8 +119,6 @@ nbtk_list_view_dispose (GObject *object)
 {
   NbtkListViewPrivate *priv = NBTK_LIST_VIEW (object)->priv;
 
-  G_OBJECT_CLASS (nbtk_list_view_parent_class)->dispose (object);
-
   /* This will cause the unref of the model and also disconnect the signals */
   nbtk_list_view_set_model (NBTK_LIST_VIEW (object), NULL);
 
@@ -129,6 +127,8 @@ nbtk_list_view_dispose (GObject *object)
       g_object_unref (priv->factory);
       priv->factory = NULL;
     }
+
+  G_OBJECT_CLASS (nbtk_list_view_parent_class)->dispose (object);
 }
 
 static void
@@ -136,15 +136,14 @@ nbtk_list_view_finalize (GObject *object)
 {
   NbtkListViewPrivate *priv = NBTK_LIST_VIEW (object)->priv;
 
-  G_OBJECT_CLASS (nbtk_list_view_parent_class)->finalize (object);
-
-
   if (priv->attributes)
     {
       g_slist_foreach (priv->attributes, (GFunc) g_free, NULL);
       g_slist_free (priv->attributes);
       priv->attributes = NULL;
     }
+
+  G_OBJECT_CLASS (nbtk_list_view_parent_class)->finalize (object);
 }
 
 static void
@@ -275,6 +274,8 @@ model_changed_cb (ClutterModel *model,
           clutter_model_iter_get_value (iter, attr->col, &value);
 
           g_object_set_property (child, attr->name, &value);
+
+          g_value_unset (&value);
         }
       g_object_thaw_notify (child);
 
@@ -411,6 +412,7 @@ nbtk_list_view_set_model (NbtkListView *list_view,
                                             (GCallback)row_removed_cb,
                                             list_view);
       g_object_unref (priv->model);
+      priv->model = NULL;
     }
 
   if (model)
