@@ -192,14 +192,23 @@ nbtk_scroll_bar_dispose (GObject *gobject)
       priv->handle = NULL;
     }
 
-  clutter_actor_unparent (priv->bw_stepper);
-  priv->bw_stepper = NULL;
+  if (priv->bw_stepper)
+    {
+      clutter_actor_unparent (priv->bw_stepper);
+      priv->bw_stepper = NULL;
+    }
 
-  clutter_actor_unparent (priv->fw_stepper);
-  priv->fw_stepper = NULL;
+  if (priv->fw_stepper)
+    {
+      clutter_actor_unparent (priv->fw_stepper);
+      priv->fw_stepper = NULL;
+    }
 
-  clutter_actor_unparent (priv->trough);
-  priv->trough = NULL;
+  if (priv->trough)
+    {
+      clutter_actor_unparent (priv->trough);
+      priv->trough = NULL;
+    }
 
   G_OBJECT_CLASS (nbtk_scroll_bar_parent_class)->dispose (gobject);
 }
@@ -972,14 +981,15 @@ stepper_button_press_event_cb (ClutterActor       *actor,
 }
 
 static gboolean
-stepper_button_release_cb (ClutterActor        *actor,
-                           ClutterButtonEvent  *event,
-                           NbtkScrollBar       *self)
+stepper_button_release_cb (ClutterActor  *actor,
+                           ClutterEvent  *event,
+                           NbtkScrollBar *self)
 {
-  if (event->button != 1)
-    return FALSE;
-
-  g_source_remove (self->priv->stepper_source_id);
+  if (self->priv->stepper_source_id)
+    {
+      g_source_remove (self->priv->stepper_source_id);
+      self->priv->stepper_source_id = 0;
+    }
 
   return FALSE;
 }
@@ -1011,6 +1021,8 @@ nbtk_scroll_bar_init (NbtkScrollBar *self)
                     G_CALLBACK (stepper_button_press_event_cb), self);
   g_signal_connect (self->priv->bw_stepper, "button-release-event",
                     G_CALLBACK (stepper_button_release_cb), self);
+  g_signal_connect (self->priv->bw_stepper, "leave-event",
+                    G_CALLBACK (stepper_button_release_cb), self);
 
   self->priv->fw_stepper = (ClutterActor *) nbtk_button_new ();
   clutter_actor_set_name (CLUTTER_ACTOR (self->priv->fw_stepper),
@@ -1021,6 +1033,8 @@ nbtk_scroll_bar_init (NbtkScrollBar *self)
                     G_CALLBACK (stepper_button_press_event_cb), self);
   g_signal_connect (self->priv->fw_stepper, "button-release-event",
                     G_CALLBACK (stepper_button_release_cb), self);
+  g_signal_connect (self->priv->fw_stepper, "leave-event",
+                    G_CALLBACK (stepper_button_release_cb), self);
 
   self->priv->trough = (ClutterActor *) nbtk_bin_new ();
   clutter_actor_set_reactive ((ClutterActor *) self->priv->trough, TRUE);
