@@ -121,8 +121,6 @@ nbtk_scroll_view_dispose (GObject *object)
 {
   NbtkScrollViewPrivate *priv = NBTK_SCROLL_VIEW (object)->priv;
 
-  priv->child = NULL;
-
   if (priv->vscroll)
     {
       clutter_actor_unparent (priv->vscroll);
@@ -135,6 +133,7 @@ nbtk_scroll_view_dispose (GObject *object)
       priv->hscroll = NULL;
     }
 
+  /* Chaining up will remove the child actor */
   G_OBJECT_CLASS (nbtk_scroll_view_parent_class)->dispose (object);
 }
 
