@@ -125,8 +125,11 @@ nbtk_container_remove_actor (ClutterContainer *container,
                              ClutterActor     *actor)
 {
   NbtkTablePrivate *priv = NBTK_TABLE (container)->priv;
+  gint rows, cols;
 
   GSList *item = NULL;
+  NbtkTableChild *meta;
+  GSList *l;
 
   item = g_slist_find (priv->children, actor);
 
@@ -143,6 +146,20 @@ nbtk_container_remove_actor (ClutterContainer *container,
   priv->children = g_slist_delete_link (priv->children, item);
   clutter_actor_unparent (actor);
 
+  /* update row/column count */
+  rows = 0;
+  cols = 0;
+  for (l = priv->children; l; l = l->next)
+    {
+      ClutterActor *child = CLUTTER_ACTOR (l->data);
+      meta = (NbtkTableChild *) clutter_container_get_child_meta (container,
+                                                                  child);
+      rows = MAX (rows, meta->row + 1);
+      cols = MAX (cols, meta->col + 1);
+    }
+  priv->n_rows = rows;
+  priv->n_cols = cols;
+
   clutter_actor_queue_relayout (CLUTTER_ACTOR (container));
 
   g_signal_emit_by_name (container, "actor-removed", actor);
@@ -291,15 +308,13 @@ static void
 nbtk_table_dispose (GObject *gobject)
 {
   NbtkTablePrivate *priv = NBTK_TABLE (gobject)->priv;
-  GSList *l, *next;
 
-  for (l = priv->children; l;)
-    {
-      next = l->next;
-      clutter_container_remove_actor ((ClutterContainer *)gobject,
-                                      CLUTTER_ACTOR (l->data));
-      l = next;
-    }
+  /* destroy the children
+   * clutter_actor_destroy() will call clutter_container_remove() which will
+   * remove the children from the internal list
+   */
+  while (priv->children)
+    clutter_actor_destroy (CLUTTER_ACTOR (priv->children->data));
 
   G_OBJECT_CLASS (nbtk_table_parent_class)->dispose (gobject);
 }
@@ -1284,7 +1299,14 @@ nbtk_table_set_col_spacing (NbtkTable *table,
 
   priv = NBTK_TABLE (table)->priv;
 
-  priv->col_spacing = spacing;
+  if (priv->col_spacing != spacing)
+    {
+      priv->col_spacing = spacing;
+
+      clutter_actor_queue_relayout (CLUTTER_ACTOR (table));
+
+      g_object_notify (G_OBJECT (table), "col-spacing");
+    }
 }
 
 /**
@@ -1305,7 +1327,14 @@ nbtk_table_set_row_spacing (NbtkTable *table,
 
   priv = NBTK_TABLE (table)->priv;
 
-  priv->row_spacing = spacing;
+  if (priv->row_spacing != spacing)
+    {
+      priv->row_spacing = spacing;
+
+      clutter_actor_queue_relayout (CLUTTER_ACTOR (table));
+
+      g_object_notify (G_OBJECT (table), "row-spacing");
+    }
 }
 
 /**
