@@ -400,6 +400,34 @@ nbtk_tooltip_unmap (ClutterActor *self)
   clutter_actor_unmap (priv->label);
 }
 
+static void
+nbtk_tooltip_dispose (GObject *object)
+{
+  NbtkTooltip *tooltip = NBTK_TOOLTIP (object);
+
+  if (tooltip->priv->label)
+    {
+      clutter_actor_destroy (tooltip->priv->label);
+      tooltip->priv->label = NULL;
+    }
+
+  G_OBJECT_CLASS (nbtk_tooltip_parent_class)->dispose (object);
+}
+
+static void
+nbtk_tooltip_finalize (GObject *object)
+{
+  NbtkTooltip *tooltip = NBTK_TOOLTIP (object);
+
+  if (tooltip->priv->tip_area)
+    {
+      g_boxed_free (CLUTTER_TYPE_GEOMETRY, tooltip->priv->tip_area);
+      tooltip->priv->tip_area = NULL;
+    }
+
+  G_OBJECT_CLASS (nbtk_tooltip_parent_class)->finalize (object);
+}
+
 static void
 nbtk_tooltip_class_init (NbtkTooltipClass *klass)
 {
@@ -411,6 +439,8 @@ nbtk_tooltip_class_init (NbtkTooltipClass *klass)
 
   gobject_class->set_property = nbtk_tooltip_set_property;
   gobject_class->get_property = nbtk_tooltip_get_property;
+  gobject_class->dispose = nbtk_tooltip_dispose;
+  gobject_class->finalize = nbtk_tooltip_finalize;
 
   actor_class->get_preferred_width = nbtk_tooltip_get_preferred_width;
   actor_class->get_preferred_height = nbtk_tooltip_get_preferred_height;
@@ -652,7 +682,7 @@ nbtk_tooltip_hide (NbtkTooltip *tooltip)
 {
   ClutterAnimation *animation;
 
-  g_return_if_fail (NBTK_TOOLTIP (tooltip));
+  g_return_if_fail (NBTK_IS_TOOLTIP (tooltip));
 
   /* make sure we're not currently already animating (e.g. hiding) */
   animation = clutter_actor_get_animation (CLUTTER_ACTOR (tooltip));
