@@ -473,17 +473,11 @@ scrollable_get_adjustments (NbtkScrollable *scrollable,
                             NbtkAdjustment **vadjustment)
 {
   NbtkViewportPrivate *priv;
-  ClutterActor *actor, *stage;
 
   g_return_if_fail (NBTK_IS_VIEWPORT (scrollable));
 
   priv = ((NbtkViewport *) scrollable)->priv;
 
-  actor = CLUTTER_ACTOR (scrollable);
-  stage = clutter_actor_get_stage (actor);
-  if (G_UNLIKELY (stage == NULL))
-    stage = clutter_stage_get_default ();
-
   if (hadjustment)
     {
       if (priv->hadjustment)
@@ -491,18 +485,16 @@ scrollable_get_adjustments (NbtkScrollable *scrollable,
       else
         {
           NbtkAdjustment *adjustment;
-          gdouble width, stage_width, increment;
 
-          width = clutter_actor_get_width (actor);
-          stage_width = clutter_actor_get_width (stage);
-          increment = MAX (1.0, MIN (stage_width, width));
+          /* create an initial adjustment. this is filled with correct values
+           * as soon as allocate() is called */
 
-          adjustment = nbtk_adjustment_new (priv->x,
-                                            0,
-                                            width,
+          adjustment = nbtk_adjustment_new (0.0,
+                                            0.0,
                                             1.0,
-                                            increment,
-                                            increment);
+                                            1.0,
+                                            1.0,
+                                            1.0);
 
           scrollable_set_adjustments (scrollable,
                                       adjustment,
@@ -519,18 +511,16 @@ scrollable_get_adjustments (NbtkScrollable *scrollable,
       else
         {
           NbtkAdjustment *adjustment;
-          gdouble height, stage_height, increment;
 
-          height = clutter_actor_get_height (actor);
-          stage_height = clutter_actor_get_height (stage);
-          increment = MAX (1.0, MIN (stage_height, height));
+          /* create an initial adjustment. this is filled with correct values
+           * as soon as allocate() is called */
 
-          adjustment = nbtk_adjustment_new (priv->y,
-                                            0,
-                                            height,
+          adjustment = nbtk_adjustment_new (0.0,
+                                            0.0,
                                             1.0,
-                                            increment,
-                                            increment);
+                                            1.0,
+                                            1.0,
+                                            1.0);
 
           scrollable_set_adjustments (scrollable,
                                       priv->hadjustment,
