@@ -205,10 +205,10 @@ nbtk_widget_dispose (GObject *gobject)
       priv->border_image = NULL;
     }
 
-  if (priv->bg_color)
+  if (priv->background_image)
     {
-      clutter_color_free (priv->bg_color);
-      priv->bg_color = NULL;
+      clutter_actor_unparent (priv->background_image);
+      priv->background_image = NULL;
     }
 
   if (priv->tooltip)
@@ -222,6 +222,8 @@ nbtk_widget_dispose (GObject *gobject)
 
       if (parent)
         clutter_container_remove_actor (parent, tooltip);
+      else
+        clutter_actor_destroy (tooltip);
 
       priv->tooltip = NULL;
     }
@@ -237,6 +239,8 @@ nbtk_widget_finalize (GObject *gobject)
   g_free (priv->style_class);
   g_free (priv->pseudo_class);
 
+  clutter_color_free (priv->bg_color);
+
   G_OBJECT_CLASS (nbtk_widget_parent_class)->finalize (gobject);
 }
 
@@ -878,7 +882,7 @@ nbtk_widget_set_style_class_name (NbtkWidget  *actor,
 {
   NbtkWidgetPrivate *priv = actor->priv;
 
-  g_return_if_fail (NBTK_WIDGET (actor));
+  g_return_if_fail (NBTK_IS_WIDGET (actor));
 
   priv = actor->priv;
 
@@ -906,7 +910,7 @@ nbtk_widget_set_style_class_name (NbtkWidget  *actor,
 const gchar*
 nbtk_widget_get_style_class_name (NbtkWidget *actor)
 {
-  g_return_val_if_fail (NBTK_WIDGET (actor), NULL);
+  g_return_val_if_fail (NBTK_IS_WIDGET (actor), NULL);
 
   return actor->priv->style_class;
 }
@@ -923,7 +927,7 @@ nbtk_widget_get_style_class_name (NbtkWidget *actor)
 const gchar*
 nbtk_widget_get_style_pseudo_class (NbtkWidget *actor)
 {
-  g_return_val_if_fail (NBTK_WIDGET (actor), NULL);
+  g_return_val_if_fail (NBTK_IS_WIDGET (actor), NULL);
 
   return actor->priv->pseudo_class;
 }
@@ -941,7 +945,7 @@ nbtk_widget_set_style_pseudo_class (NbtkWidget  *actor,
 {
   NbtkWidgetPrivate *priv;
 
-  g_return_if_fail (NBTK_WIDGET (actor));
+  g_return_if_fail (NBTK_IS_WIDGET (actor));
 
   priv = actor->priv;
 
